@@ -25,7 +25,7 @@ class reminder():
                 result = func(*args, **kwargs)
                 self.post()
                 return result
-            except:
+            finally:
                 self.post(error=1)
         return do
 
